import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
 csv,
  scaleLinear, scaleTime,
  max,
  format, timeFormat,
  extent,
  histogram as bin,
  timeMonths,
  sum
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 40,
  bottom: 65,
  left: 90,
};
const innerHeight =
  height - margin.top - margin.bottom;
const innerWidth =
  width - margin.left - margin.right;
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 50;

const App = () => {
  const data = useData();

  console.log(data);
  if (!data) {
    return <pre>Loading...</pre>;
  }

  const xValue = d => d['Reported Date'];
  const yValue = d => d['Total Dead and Missing'];

  const xAxisLabel = 'Time';
  const yAxisLabel = 'Total Dead and Missing';


  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  .nice();

  

  const [start, stop] = xScale.domain();
  
  const binnedData = bin()
  .value(xValue)
  .domain(xScale.domain())
  .thresholds(timeMonths(start, stop))(data)
  .map(array => ({
  	y: sum(array, yValue),
  	x0: array.x0,
    x1: array.x1
  }))
  

  
    const yScale = scaleLinear()
    .domain([0, max(binnedData, d=>d.y)])
    .range([innerHeight, 0])
    .nice();

    //console.log(yScale.domain())
  

  //console.log(xScale.ticks());

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat = {n=>timeFormat('%m/%Y')(n)}
          tickOffset = {7}
        />
        <AxisLeft yScale={yScale} innerWidth={innerWidth}  tickOffset = {7}/>
         <text className="axis-label" 
           
          textAnchor="middle"
           transform = {`translate(${-yAxisLabelOffset}, ${innerHeight/2} ) rotate(-90) `}
           >{yAxisLabel}</text>
        

        <text className="axis-label" x={innerWidth/2} 
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle" >{xAxisLabel}</text>
        
        
        <Marks
          binnedData={binnedData}
          xScale={xScale}
          yScale={yScale}
  
          innerHeight = {innerHeight}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById(
  'root'
);

ReactDOM.render(<App />, rootElement);
